@@ -106,7 +106,7 @@ public class GDE {
 	private static boolean									isWithUi													= false;
 
 	// ****** begin global constants section *******
-	public static final String							VERSION														= "Version 3.9.3"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
+	public static final String							VERSION														= "Version 3.9.4"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
 	public static final int									VERSION_NUMBER										= GDE.VERSION.contains("beta") 
 															? Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY)) - 1
 															: Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY));
@@ -125,6 +125,7 @@ public class GDE {
 	public static final boolean							IS_MAC_COCOA											= GDE.IS_MAC && System.getProperty("DO_NOT_USE_COCOA") == null && SWT.getPlatform().toLowerCase().startsWith("cocoa");			//$NON-NLS-1$ //$NON-NLS-2$
 	public static final boolean							IS_ARCH_DATA_MODEL_64							= System.getProperty("sun.arch.data.model").equals("64");																																		//$NON-NLS-1$ //$NON-NLS-2$
 	public static final boolean							IS_OS_ARCH_ARM										= System.getProperty("os.arch").toLowerCase().startsWith("arm") || System.getProperty("os.arch").toLowerCase().startsWith("aarch");	//$NON-NLS-1$ //$NON-NLS-2$
+	public static final boolean							isSystemDarkTheme									= GDE.isSystemDarkTheme();
 
 	/** Depends on the Operating System type. Is empty if no valid OS. */
 	public static final String							APPL_HOME_PATH										= GDE.IS_WINDOWS
@@ -784,4 +785,13 @@ public class GDE {
 		}
 		return GDE.uiNotification;
 	}
+	
+	/**
+	 * @return if dark theme is configured, ARM 32 swt.jar is to old and does not know dark theme 
+	 */
+	public static boolean isSystemDarkTheme() {
+		if (GDE.IS_OS_ARCH_ARM || GDE.IS_WINDOWS)
+			return false;
+		return Display.isSystemDarkTheme();
+	}
 }
