@@ -712,8 +712,8 @@ public class StringHelper {
 	 * @return string with converted characters
 	 */
 	public static String byte2Hex2CharString(byte[] bytes, int start, int size) {
-		StringBuffer sb = new StringBuffer().append(GDE.STRING_LEFT_BRACKET).append(String.format("%3d", size-start)).append(GDE.STRING_RIGHT_BRACKET_COMMA);
-		for (int i = start; i < size; i++) {
+		StringBuffer sb = new StringBuffer().append(GDE.STRING_LEFT_BRACKET).append(String.format("%3d", size)).append(GDE.STRING_RIGHT_BRACKET_COMMA);
+		for (int i = start; i < size+start; i++) {
 			sb.append(String.format(" %02X", bytes[i])); //$NON-NLS-1$
 		}
 		return sb.toString();
